@@ -1,9 +1,9 @@
 #ifndef VALIDITY_CHECK_COX_VALIDITY_CHECK_MODEL_H
 #define VALIDITY_CHECK_COX_VALIDITY_CHECK_MODEL_H
 
-#include "basedef.h"
-#include "data/data_set.h"
-#include "model/cox_model.h"
+#include "../basedef.h"
+#include "../data/data_set.h"
+#include "../model/cox_model.h"
 
 bool validity_check_model(const data_set& data, const mat& theta, unsigned t,
   const cox_model& model) {
